@@ -3,20 +3,42 @@ from . import fields
 from .animation import Animation
 from .audio import Audio
 from .auth_widget_data import AuthWidgetData
+from .bot_command import BotCommand
+from .bot_command_scope import BotCommandScope, BotCommandScopeAllChatAdministrators, \
+    BotCommandScopeAllGroupChats, BotCommandScopeAllPrivateChats, BotCommandScopeChat, \
+    BotCommandScopeChatAdministrators, BotCommandScopeChatMember, \
+    BotCommandScopeDefault, BotCommandScopeType
 from .callback_game import CallbackGame
 from .callback_query import CallbackQuery
 from .chat import Chat, ChatActions, ChatType
-from .chat_member import ChatMember, ChatMemberStatus
+from .chat_administrator_rights import ChatAdministratorRights
+from .chat_invite_link import ChatInviteLink
+from .chat_join_request import ChatJoinRequest
+from .chat_location import ChatLocation
+from .chat_member import ChatMember, ChatMemberAdministrator, ChatMemberBanned, \
+    ChatMemberLeft, ChatMemberMember, ChatMemberOwner, ChatMemberRestricted, \
+    ChatMemberStatus
+from .chat_member_updated import ChatMemberUpdated
+from .chat_permissions import ChatPermissions
 from .chat_photo import ChatPhoto
+from .chat_shared import ChatShared
 from .chosen_inline_result import ChosenInlineResult
 from .contact import Contact
+from .dice import Dice, DiceEmoji
 from .document import Document
 from .encrypted_credentials import EncryptedCredentials
 from .encrypted_passport_element import EncryptedPassportElement
 from .file import File
 from .force_reply import ForceReply
+from .forum_topic import ForumTopic
+from .forum_topic_closed import ForumTopicClosed
+from .forum_topic_created import ForumTopicCreated
+from .forum_topic_edited import ForumTopicEdited
+from .forum_topic_reopened import ForumTopicReopened
 from .game import Game
 from .game_high_score import GameHighScore
+from .general_forum_topic_hidden import GeneralForumTopicHidden
+from .general_forum_topic_unhidden import GeneralForumTopicUnhidden
 from .inline_keyboard import InlineKeyboardButton, InlineKeyboardMarkup
 from .inline_query import InlineQuery
 from .inline_query_result import InlineQueryResult, InlineQueryResultArticle, InlineQueryResultAudio, \
@@ -29,14 +51,17 @@ from .input_file import InputFile
 from .input_media import InputMedia, InputMediaAnimation, InputMediaAudio, InputMediaDocument, InputMediaPhoto, \
     InputMediaVideo, MediaGroup
 from .input_message_content import InputContactMessageContent, InputLocationMessageContent, InputMessageContent, \
-    InputTextMessageContent, InputVenueMessageContent
+    InputTextMessageContent, InputVenueMessageContent, InputInvoiceMessageContent
 from .invoice import Invoice
 from .labeled_price import LabeledPrice
 from .location import Location
 from .login_url import LoginUrl
 from .mask_position import MaskPosition
+from .menu_button import MenuButton, MenuButtonCommands, MenuButtonWebApp, MenuButtonDefault
 from .message import ContentType, ContentTypes, Message, ParseMode
+from .message_auto_delete_timer_changed import MessageAutoDeleteTimerChanged
 from .message_entity import MessageEntity, MessageEntityType
+from .message_id import MessageId
 from .order_info import OrderInfo
 from .passport_data import PassportData
 from .passport_element_error import PassportElementError, PassportElementErrorDataField, PassportElementErrorFile, \
@@ -44,10 +69,13 @@ from .passport_element_error import PassportElementError, PassportElementErrorDa
     PassportElementErrorSelfie
 from .passport_file import PassportFile
 from .photo_size import PhotoSize
-from .poll import PollOption, Poll
+from .poll import PollOption, Poll, PollAnswer, PollType
 from .pre_checkout_query import PreCheckoutQuery
-from .reply_keyboard import KeyboardButton, ReplyKeyboardMarkup, ReplyKeyboardRemove
+from .proximity_alert_triggered import ProximityAlertTriggered
+from .reply_keyboard import KeyboardButton, ReplyKeyboardMarkup, ReplyKeyboardRemove, KeyboardButtonPollType, \
+    KeyboardButtonRequestChat, KeyboardButtonRequestUser
 from .response_parameters import ResponseParameters
+from .sent_web_app_message import SentWebAppMessage
 from .shipping_address import ShippingAddress
 from .shipping_option import ShippingOption
 from .shipping_query import ShippingQuery
@@ -57,34 +85,71 @@ from .successful_payment import SuccessfulPayment
 from .update import AllowedUpdates, Update
 from .user import User
 from .user_profile_photos import UserProfilePhotos
+from .user_shared import UserShared
 from .venue import Venue
 from .video import Video
+from .video_chat_ended import VideoChatEnded
+from .video_chat_participants_invited import VideoChatParticipantsInvited
+from .video_chat_scheduled import VideoChatScheduled
+from .video_chat_started import VideoChatStarted
 from .video_note import VideoNote
 from .voice import Voice
+from .voice_chat_ended import VoiceChatEnded
+from .voice_chat_participants_invited import VoiceChatParticipantsInvited
+from .voice_chat_scheduled import VoiceChatScheduled
+from .voice_chat_started import VoiceChatStarted
+from .web_app_data import WebAppData
+from .web_app_info import WebAppInfo
 from .webhook_info import WebhookInfo
+from .write_access_allowed import WriteAccessAllowed
 
 __all__ = (
     'AllowedUpdates',
     'Animation',
     'Audio',
     'AuthWidgetData',
+    'BotCommand',
+    'BotCommandScope',
+    'BotCommandScopeAllChatAdministrators',
+    'BotCommandScopeAllGroupChats',
+    'BotCommandScopeAllPrivateChats',
+    'BotCommandScopeChat',
+    'BotCommandScopeChatAdministrators',
+    'BotCommandScopeChatMember',
+    'BotCommandScopeDefault',
+    'BotCommandScopeType',
     'CallbackGame',
     'CallbackQuery',
     'Chat',
     'ChatActions',
+    'ChatAdministratorRights',
+    'ChatInviteLink',
+    'ChatJoinRequest',
+    'ChatLocation',
     'ChatMember',
     'ChatMemberStatus',
+    'ChatMemberUpdated',
+    'ChatMemberOwner',
+    'ChatMemberAdministrator',
+    'ChatMemberMember',
+    'ChatMemberRestricted',
+    'ChatMemberLeft',
+    'ChatMemberBanned',
+    'ChatPermissions',
     'ChatPhoto',
     'ChatType',
     'ChosenInlineResult',
     'Contact',
     'ContentType',
     'ContentTypes',
+    'Dice',
+    'DiceEmoji',
     'Document',
     'EncryptedCredentials',
     'EncryptedPassportElement',
     'File',
     'ForceReply',
+    'ForumTopic',
     'Game',
     'GameHighScore',
     'InlineKeyboardButton',
@@ -112,6 +177,7 @@ __all__ = (
     'InlineQueryResultVideo',
     'InlineQueryResultVoice',
     'InputContactMessageContent',
+    'InputInvoiceMessageContent',
     'InputFile',
     'InputLocationMessageContent',
     'InputMedia',
@@ -125,14 +191,23 @@ __all__ = (
     'InputVenueMessageContent',
     'Invoice',
     'KeyboardButton',
+    'KeyboardButtonPollType',
+    'KeyboardButtonRequestChat',
+    'KeyboardButtonRequestUser',
     'LabeledPrice',
     'Location',
     'LoginUrl',
     'MaskPosition',
+    'MenuButton',
+    'MenuButtonCommands',
+    'MenuButtonWebApp',
+    'MenuButtonDefault',
     'MediaGroup',
     'Message',
+    'MessageAutoDeleteTimerChanged',
     'MessageEntity',
     'MessageEntityType',
+    'MessageId',
     'OrderInfo',
     'ParseMode',
     'PassportData',
@@ -146,11 +221,15 @@ __all__ = (
     'PassportFile',
     'PhotoSize',
     'Poll',
+    'PollAnswer',
     'PollOption',
+    'PollType',
     'PreCheckoutQuery',
+    'ProximityAlertTriggered',
     'ReplyKeyboardMarkup',
     'ReplyKeyboardRemove',
     'ResponseParameters',
+    'SentWebAppMessage',
     'ShippingAddress',
     'ShippingOption',
     'ShippingQuery',
@@ -162,9 +241,28 @@ __all__ = (
     'UserProfilePhotos',
     'Venue',
     'Video',
+    'VideoChatEnded',
+    'VideoChatParticipantsInvited',
+    'VideoChatScheduled',
+    'VideoChatStarted',
     'VideoNote',
     'Voice',
+    'VoiceChatEnded',
+    'VoiceChatParticipantsInvited',
+    'VoiceChatScheduled',
+    'VoiceChatStarted',
+    'WebAppData',
+    'WebAppInfo',
     'WebhookInfo',
+    'ForumTopicCreated',
+    'ForumTopicClosed',
+    'ForumTopicReopened',
+    'ForumTopicEdited',
+    'GeneralForumTopicHidden',
+    'GeneralForumTopicUnhidden',
+    'WriteAccessAllowed',
+    "ChatShared",
+    "UserShared",
     'base',
     'fields',
 )
